GitHubPlatform class

GitHub implementation of GitPlatform.

Implemented types

Constructors

GitHubPlatform({ProcessRunner? processRunner})
Constructor accepts an optional process runner for testing.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildBaseUrl(String org, [String? project]) String
Builds the base URL for the organization.
override
buildRepoUrl(String org, String repo, [String? project]) String
Builds the full clone URL for a repository.
override
extractOrgFromUrl(String url) Organization?
Extracts organization information from a URL.
override
fetchOrgRepos(String org, {String? project, Client? client}) Future<List<Repository>>
Fetches the list of repositories for an organization.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited