UrlParser class

Unified URL parser for different git platforms.

Constructors

UrlParser()
Constructor
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatform(String type) GitPlatform
Returns the platform instance based on type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String targetArg) ParseResult
Parses the given targetArg and returns ParseResult
parseAzure(String url) ParseResult
Internal helper to parse Azure URLs. Not intended for external use.
parseGitHubSsh(String url) ParseResult
Internal helper to parse GitHub SSH URLs. Not intended for external use.
parseHttp(String url) ParseResult
Internal helper to parse HTTP URLs. Not intended for external use.
parsePlainRepo(String repo) ParseResult
Internal helper to parse plain repo names. Not intended for external use.
parseUsernameRepo(String target) ParseResult
Internal helper to parse username/repo format. Not intended for external use.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited